@@ -34,8 +34,14 @@ import warnings
 import weakref
 
 import lmdb
+try:
+    from lmdb import _config
+except ImportError:
+    _config = None
 
-__all__ = ['Environment', 'Cursor', 'Transaction', 'open', 'enable_drop_gil']
+
+__all__ = ['Environment', 'Cursor', 'Transaction', 'open',
+           'enable_drop_gil', 'version']
 __all__ += ['Error', 'KeyExistsError', 'NotFoundError', 'PageNotFoundError',
             'CorruptedError', 'PanicError', 'VersionMismatchError',
             'InvalidError', 'MapFullError', 'DbsFullError', 'ReadersFullError',
@@ -145,6 +151,10 @@ _CFFI_CDEF = '''
     int mdb_reader_list(MDB_env *env, MDB_msg_func *func, void *ctx);
     int mdb_reader_check(MDB_env *env, int *dead);
 
+    #define MDB_VERSION_MAJOR ...
+    #define MDB_VERSION_MINOR ...
+    #define MDB_VERSION_PATCH ...
+
     #define EACCES ...
     #define EAGAIN ...
     #define EINVAL ...
@@ -247,13 +257,27 @@ _CFFI_VERIFY = '''
 
 if not lmdb._reading_docs():
     import cffi
+
+    # Try to use distutils-bundled cffi configuration to avoid a recompile and
+    # potential compile errors during first module import.
+    _config_vars = _config.CONFIG if _config else {
+        'extra_sources': ['lib/mdb.c', 'lib/midl.c'],
+        'extra_include_dirs': ['lib'],
+        'extra_library_dirs': [],
+        'libraries': []
+    }
+
     _ffi = cffi.FFI()
     _ffi.cdef(_CFFI_CDEF)
     _lib = _ffi.verify(_CFFI_VERIFY,
+        modulename='lmdb_cffi',
         ext_package='lmdb',
-        sources=['lib/mdb.c', 'lib/midl.c'],
+        sources=_config_vars['extra_sources'],
         extra_compile_args=['-Wno-shorten-64-to-32'],
-        include_dirs=['lib'])
+        include_dirs=_config_vars['extra_include_dirs'],
+        libraries=_config_vars['libraries'],
+        library_dirs=_config_vars['extra_library_dirs'])
+
     globals().update((k, getattr(_lib, k))
                      for k in dir(_lib) if k[:4] in ('mdb_', 'MDB_', 'pymd'))
     EACCES = _lib.EACCES
@@ -449,6 +473,14 @@ def enable_drop_gil():
     *Caution:* this function should be invoked before any threads are created.
     """
 
+def version():
+    """
+    Return a tuple of integers `(major, minor, patch)` describing the LMDB
+    library version that the binding is linked against. The version of the
+    binding itself is available from ``lmdb.__version__``.
+    """
+    return (MDB_VERSION_MAJOR, MDB_VERSION_MINOR, MDB_VERSION_PATCH)
+
 
 class Environment(object):
     """
@@ -511,7 +543,7 @@ class Environment(object):
             If ``True`` LMDB will use a writeable memory map to update the
             database. This option is incompatible with nested transactions.
 
-        'map_async':
+        `map_async`:
              When ``writemap=True``, use asynchronous flushes to disk. As with
              ``sync=False``, a system crash can then corrupt the database or
              lose the last transactions. Calling :py:meth:`sync` ensures
